@@ -100,6 +100,7 @@ static char *models[] =
 	"AMD Athlon(tm) 64 Processor 3700+", "x86_64",
 	"AMD Athlon(tm) 64 X2 Dual Core Processor 5400+", "x86_64",
 	"AMD Phenom(tm) II X6 1055T Processor", "Phenom II",
+	"AMD A6-6310 APU with AMD Radeon R4 Graphics", "AMD A6-6310 with Radeon R4",
         "Am5x86", "5x86",
         "C6", "C6",
 	"C6-2", "C6-2",
@@ -154,7 +155,6 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 	int processors = 0; 
 	float bogomips = 0.0;
 	float tempMHz = 0.0;
-	float tempbogo;
 
 	char *p;
 
@@ -225,7 +225,10 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 		}
 	}
 
-	sprintf(hw->hw_bogomips, "%0.2f", bogomips);
+	if (bogomips == 0.0)
+		sprintf(hw->hw_bogomips, "?");
+	else
+		sprintf(hw->hw_bogomips, "%0.2f", bogomips);
 
 	if (tempMHz == 0.0)
 		sprintf(hw->hw_megahertz, "?");
